/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#ifndef CU_H
#define CU_H
/*
**	does not include <list.h>
*/
#include <stdio.h>
#include <usystype.h>

extern char *progname;

VPTR curealloc();
VPTR cumalloc();
void cufree();
VPTR cudupmem();

char *allocstr();

void cuerror();
void cumsg();

int nmprintf(char *, ...);

FILE *efopen();

char *whereami();

double elapsedtime();

#endif
